@@ -37,7 +37,7 @@ def user_with_roles(udm, random_string):
         dn=user_dn,
         username=username,
         guardianInheritedRoles=g_roles,
-        guardianRoles=u_roles
+        guardianRoles=u_roles,
     )
 
 
@@ -223,7 +223,7 @@ def test_role_attributes_on_modules():
         'users/self',
     ]
     expected = {
-        'guardianRoles': inherited_roles_mods + ["users/ldap"],
+        'guardianRoles': [*inherited_roles_mods, 'users/ldap'],
         'guardianMemberRoles': ['groups/group'],
         'guardianInheritedRoles': inherited_roles_mods,
     }
