@@ -1,12 +1,12 @@
 #!/usr/share/ucs-test/runner /usr/share/ucs-test/playwright
 ## desc: Test accessing UMC UDM LDAP module with new access token
-## tags: [keycloak]
+## tags: [keycloak, skip_admember]
 ## roles: [domaincontroller_master]
 ## exposure: dangerous
 
 import time
 from html.parser import HTMLParser
-from typing import Any, Dict
+from typing import Any
 
 import pytest
 import requests
@@ -33,14 +33,14 @@ class ExtractFormAction(HTMLParser):
 
 
 @pytest.fixture()
-def disable_saml_oauthbearer_grace(ucr_proper):
+def disable_sasl_oauthbearer_grace(ucr_proper):
     ucrv = 'ldap/server/sasl/oauthbearer/grace-time'
     original = ucr_proper.get(ucrv, None)
 
     ucr_update(ucr_proper, {ucrv: str(OAUTH_BEARER_GRACE)})
     run_command(['systemctl', 'restart', 'slapd'])
     run_command(['systemctl', 'restart', 'univention-management-console-server'])
-    time.sleep(15)
+    time.sleep(60)
 
     yield
 
@@ -48,6 +48,10 @@ def disable_saml_oauthbearer_grace(ucr_proper):
     run_command(['systemctl', 'restart', 'slapd'])
     run_command(['systemctl', 'restart', 'univention-management-console-server'])
 
+    # Restarting the UMC in multiprcessing takes some time. Wait here until it's running again
+    # Otherwise the next test might fail because UMC is not ready yet.
+    time.sleep(30)
+
 
 @pytest.fixture()
 def umc_base_url(portal_config):
@@ -59,11 +63,11 @@ def client():
     return requests.Session()
 
 
-def set_access_token_expiry_time(client: Dict[Any, Any]):
+def set_access_token_expiry_time(client: dict[Any, Any]):
     client['attributes']['access.token.lifespan'] = str(ACCESS_TOKEN_LIFESPAN)
 
 
-@pytest.mark.usefixtures('modify_keycloak_clients', 'disable_saml_oauthbearer_grace')
+@pytest.mark.usefixtures('modify_keycloak_clients', 'disable_sasl_oauthbearer_grace')
 @pytest.mark.parametrize('modify_keycloak_clients', [set_access_token_expiry_time], indirect=True)
 def test_udm_module_with_new_access_token(umc_base_url: str, client: requests.Session):
     resp = client.get(f'{umc_base_url}/oidc/')
@@ -85,9 +89,9 @@ def test_udm_module_with_new_access_token(umc_base_url: str, client: requests.Se
     assert client.cookies.get('UMCSessionId') is not None, "No UMCSessionId cookie after login"
     umc_request_body = {
         "options": {
-            "objectType": "users/user"
+            "objectType": "users/user",
         },
-        "flavor": "users/user"
+        "flavor": "users/user",
     }
 
     xsrf_header = {'X-Xsrf-Protection': client.cookies.get('UMCSessionId')}
