@@ -8,14 +8,21 @@ from __future__ import annotations
 
 import subprocess
 import time
-from typing import Callable, Iterator, Type
+from typing import TYPE_CHECKING
 
 import pytest
 
-import univention.lib.umc
+from univention.appcenter.actions import get_action
+from univention.appcenter.app_cache import Apps
 from univention.testing import selenium as _sel, strings, ucr as _ucr, udm as _udm, umc, utils
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterator
+
+    import univention.lib.umc
+
+
 pytest_plugins = ["univention.testing.conftest"]
 
 
@@ -92,7 +99,7 @@ def selenium() -> Iterator[_sel.UMCSeleniumTest]:
 
 
 @pytest.fixture(scope='session')
-def Client() -> Type[umc.Client]:
+def Client() -> type[umc.Client]:
     """Session scoped client factory to access UMC."""
     return umc.Client
 
@@ -142,3 +149,30 @@ def wait_for_replication() -> Callable[..., None]:
 @pytest.fixture(scope='session')
 def account() -> utils.UCSTestDomainAdminCredentials:
     return utils.UCSTestDomainAdminCredentials()
+
+
+@pytest.fixture()
+def change_app_setting():
+    """Change settings of an app and revert"""
+    data = {'app': None, 'configure': None, 'changes': {}}
+
+    def _func(app_id: str, changes: dict, revert: bool = True) -> None:
+        apps_cache = Apps()
+        app = apps_cache.find(app_id, latest=True)
+        data['app'] = app
+        configure = get_action('configure')
+        data['configure'] = configure
+        settings = configure.list_config(app)
+        known_settings = {x.get('name'): x.get('value') for x in settings}
+        for change in changes:
+            if change in known_settings:
+                if revert:
+                    data['changes'][change] = known_settings[change]
+            else:
+                raise Exception(f'Unknown setting: {change}')
+        configure.call(app=app, set_vars=changes)
+
+    yield _func
+
+    if data['changes']:
+        data['configure'].call(app=data['app'], set_vars=data['changes'])
