@@ -34,7 +34,8 @@
 
 """conftest plugin for pytest runner in ucs-test"""
 
-from typing import Callable, TypeVar
+from collections.abc import Callable
+from typing import TypeVar
 
 import pytest
 from _pytest.config import Config
@@ -161,6 +162,6 @@ def locale_available(*locales: str) -> Callable[[_F], _F]:  # Py3.10+: ParamSpec
     required = set(locales) or {"de_DE", "en_US"}
 
     return pytest.mark.skipif(
-        not required <= available,
-        reason="Required locales {} are not available {}".format(",".join(required), ",".join(available)),
+        available < required,
+        reason="Required locales are not available",
     )
