@@ -59,7 +59,7 @@ import subprocess
 import sys
 import time
 from inspect import getfullargspec
-from typing import Any, Dict, Iterable, List, Mapping, Sequence, Tuple
+from typing import TYPE_CHECKING, Any
 
 import ldap
 import ldap.filter
@@ -74,6 +74,10 @@ from univention.testing import utils
 from univention.testing.ucs_samba import DRSReplicationFailed, wait_for_drs_replication
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Mapping, Sequence
+
+
 class UCSTestUDM_Exception(Exception):
 
     def __str__(self):
@@ -150,7 +154,7 @@ class UCSTestUDM:
         'computers/ipmanagedclient')
 
     # map identifying UDM module or rdn-attribute to samba4 rdn attribute
-    def ad_object_identifying_filter(self, modulename: str, dn: str) -> Dict[str, str] | None:
+    def ad_object_identifying_filter(self, modulename: str, dn: str) -> dict[str, str] | None:
         udm_mainmodule, udm_submodule = modulename.split('/', 1)
         objname = ldap.dn.str2dn(dn)[0][0][1]
 
@@ -194,7 +198,7 @@ class UCSTestUDM:
 
         if match_filter:
             try:
-                res = self._lo.search(base=dn, filter=match_filter, scope='base', attr=[])
+                res = self._primary_lo.search(base=dn, filter=match_filter, scope='base', attr=[])
             except ldap.NO_SUCH_OBJECT:
                 print(f"OpenLDAP object to check against S4-Connector match_filter doesn't exist: {dn}")
                 res = None  # TODO: This happens during delete. By setting res=None here, we will not wait for DRS replication for deletes!
@@ -211,6 +215,7 @@ class UCSTestUDM:
             return ad_ldap_search_args
 
     __lo = None
+    __primary_lo = None
     __ucr = None
 
     @property
@@ -219,6 +224,14 @@ class UCSTestUDM:
             self.__lo = utils.get_ldap_connection()
         return self.__lo
 
+    @property
+    def _primary_lo(self) -> univention.admin.uldap.access:
+        if self._ucr.get('server/role') == 'domaincontroller_master':
+            return self._lo
+        if self.__primary_lo is None:
+            self.__primary_lo = utils.get_ldap_connection(primary=True)
+        return self.__primary_lo
+
     @property
     def _ucr(self) -> univention.testing.ucr.UCSTestConfigRegistry:
         if self.__ucr is None:
@@ -250,7 +263,7 @@ class UCSTestUDM:
             self._env['LANG'] = '%s.UTF-8' % (language.replace('-', '_'),)
 
     @classmethod
-    def _build_udm_cmdline(cls, modulename: str, action: str, kwargs: Dict[str, Any]) -> List[str]:
+    def _build_udm_cmdline(cls, modulename: str, action: str, kwargs: dict[str, Any]) -> list[str]:
         """
         Pass modulename, action (create, modify, delete) and a bunch of keyword arguments
         to _build_udm_cmdline to build a command for UDM CLI.
@@ -286,7 +299,7 @@ class UCSTestUDM:
             if arg not in args:
                 continue
             value = args.pop(arg)
-            if not isinstance(value, (list, tuple)):
+            if not isinstance(value, list | tuple):
                 value = (value,)
             for item in value:
                 cmd.extend(['--%s' % arg.replace('_', '-'), item])
@@ -306,7 +319,7 @@ class UCSTestUDM:
             cmd.extend(['--option', option])
 
         for key, value in args.pop('set', {}).items():
-            if isinstance(value, (list, tuple)):
+            if isinstance(value, list | tuple):
                 for item in value:
                     cmd.extend(['--set', f'{key}={item}'])
             else:
@@ -328,7 +341,7 @@ class UCSTestUDM:
 
         # set all other remaining properties
         for key, value in args.items():
-            if isinstance(value, (list, tuple)):
+            if isinstance(value, list | tuple):
                 for item in value:
                     cmd.extend(['--append', f'{key}={item}'])
             elif value:
@@ -359,7 +372,7 @@ class UCSTestUDM:
 
         # find DN of freshly created object and add it to cleanup list
         for line in stdout.splitlines():  # :pylint: disable-msg=E1103
-            if line.startswith('Object created: ') or line.startswith('Object exists: '):
+            if line.startswith(('Object created: ', 'Object exists: ')):
                 dn = line.split(': ', 1)[-1]
                 if not line.startswith('Object exists: '):
                     self._cleanup.setdefault(modulename, []).append(dn)
@@ -370,7 +383,7 @@ class UCSTestUDM:
         self.wait_for(modulename, dn, wait_for_replication, everything=wait_for)
         return dn
 
-    def create_with_defaults(self, modulename: str, **kwargs: Any) -> Tuple[str, dict]:
+    def create_with_defaults(self, modulename: str, **kwargs: Any) -> tuple[str, dict]:
         """Create any object with as maximum as possible prefilled random default values"""
         module = univention.admin.modules._get(modulename)
         # TODO: cache objects
@@ -884,7 +897,7 @@ class UCSTestUDM:
 
     def wait_for(self, modulename: str, dn: str, wait_for_replication: bool = True, wait_for_drs_replication: bool = False, wait_for_s4connector: bool = False, everything: bool = False) -> None:
         # the order of the conditions is imporant
-        conditions: List[Tuple[utils.ReplicationType, bool]] = []
+        conditions: list[tuple[utils.ReplicationType, bool]] = []
         if wait_for_replication:
             conditions.append((utils.ReplicationType.LISTENER, wait_for_replication))
 
@@ -910,7 +923,7 @@ class UCSTestUDM:
 
         return utils.wait_for(conditions, verbose=False)
 
-    def create_user(self, wait_for_replication: bool = True, check_for_drs_replication: bool = True, wait_for: bool = True, **kwargs: Any) -> Tuple[str, str]:  # :pylint: disable-msg=W0613
+    def create_user(self, wait_for_replication: bool = True, check_for_drs_replication: bool = True, wait_for: bool = True, **kwargs: Any) -> tuple[str, str]:  # :pylint: disable-msg=W0613
         """
         Creates a user via UDM CLI. Values for UDM properties can be passed via keyword arguments only and
         have to exactly match UDM property names (case-sensitive!). Some properties have default values:
@@ -932,7 +945,7 @@ class UCSTestUDM:
 
         return (self.create_object('users/user', wait_for_replication, check_for_drs_replication, wait_for=wait_for, **attr), attr['username'])
 
-    def create_ldap_user(self, wait_for_replication: bool = True, check_for_drs_replication: bool = False, **kwargs: Any) -> Tuple[str, str]:  # :pylint: disable-msg=W0613
+    def create_ldap_user(self, wait_for_replication: bool = True, check_for_drs_replication: bool = False, **kwargs: Any) -> tuple[str, str]:  # :pylint: disable-msg=W0613
         # check_for_drs_replication=False -> ldap users are not replicated to s4
         attr = self._set_module_default_attr(kwargs, (
             ('position', 'cn=users,%s' % self.LDAP_BASE),
@@ -951,7 +964,7 @@ class UCSTestUDM:
         }
         self.remove_object('users/user', wait_for_replication, **kwargs)
 
-    def create_group(self, wait_for_replication: bool = True, check_for_drs_replication: bool = True, **kwargs: Any) -> Tuple[str, str]:  # :pylint: disable-msg=W0613
+    def create_group(self, wait_for_replication: bool = True, check_for_drs_replication: bool = True, **kwargs: Any) -> tuple[str, str]:  # :pylint: disable-msg=W0613
         """
         Creates a group via UDM CLI. Values for UDM properties can be passed via keyword arguments only and
         have to exactly match UDM property names (case-sensitive!). Some properties have default values:
@@ -988,7 +1001,7 @@ class UCSTestUDM:
         if ad_ldap_search_args:
             wait_for_drs_replication(should_exist=False, verbose=verbose, timeout=20, **ad_ldap_search_args)
 
-    def list_objects(self, modulename: str, **kwargs: Any) -> List[Tuple[str, Dict[str, Any]]]:
+    def list_objects(self, modulename: str, **kwargs: Any) -> list[tuple[str, dict[str, Any]]]:
         cmd = self._build_udm_cmdline(modulename, 'list', kwargs)
         print(f'Listing {modulename} objects {_prettify_cmd(cmd)}')
         returncode, stdout, stderr = self._execute_udm(cmd)
@@ -996,9 +1009,9 @@ class UCSTestUDM:
         if returncode:
             raise UCSTestUDM_ListUDMObjectFailed(returncode, stdout, stderr)
 
-        objects: List[Tuple[str, Dict[str, Any]]] = []
+        objects: list[tuple[str, dict[str, Any]]] = []
         dn = None
-        attrs: Dict[str, Any] = {}
+        attrs: dict[str, Any] = {}
         pattr = None
         pvalue = None
         pdn = None
@@ -1141,7 +1154,7 @@ class UDM(UCSTestUDM):
 
     PATH_UDM_CLI_CLIENT_WRAPPED = '/usr/sbin/udm-test-rest'
 
-    def list_objects_json(self, modulename: str, **kwargs: Any) -> List[Tuple[str, Dict[str, Any]]]:
+    def list_objects_json(self, modulename: str, **kwargs: Any) -> list[tuple[str, dict[str, Any]]]:
         kwargs['as_json'] = True
         cmd = self._build_udm_cmdline(modulename, 'list', kwargs)
         print(f'Listing {modulename} objects {_prettify_cmd(cmd)}')
@@ -1208,9 +1221,9 @@ def verify_udm_object(module: Any, dn: str, expected_properties: Mapping[str, by
         udm_value = udm_object.info.get(key, [])
         if udm_value is None:
             udm_value = []
-        if isinstance(udm_value, (bytes, str)):
+        if isinstance(udm_value, bytes | str):
             udm_value = {udm_value}
-        if not isinstance(value, (tuple, list)):
+        if not isinstance(value, tuple | list):
             value = {value}
         value = {_to_unicode(v).lower() for v in value}
         udm_value = {_to_unicode(v).lower() for v in udm_value}
